@@ -10,6 +10,10 @@ __all__ = ("Validator", "AddToDatabase", "FunctionQueryResult", "Function",
 
 import re  # for validation of function/program names
 import logging
+from datetime import datetime
+import os
+import getpass
+from collections import namedtuple
 
 from neo4jrestclient.client import GraphDatabase
 import neo4jrestclient.client as client
@@ -45,12 +49,16 @@ class Validator():
 class AddToDatabase():
     """Updates the database, adding functions/calls to a given program"""
 
-    def __init__(self, program_name='', sextant_connection=None):
+    def __init__(self, program_name='', sextant_connection=None,
+                 uploader='', uploader_id='', date=None):
         """
         Object which can be used to add functions and calls to a new program
         :param program_name: the name of the new program to be created
           (must already be validated against Validator)
         :param sextant_connection: the SextantConnection to use for connections
+        :param uploader: string identifier of user who is uploading
+        :param uploader_id: string Unix user-id of logged-in user
+        :param date: string date of today
         """
         # program_name must be alphanumeric, to avoid injection attacks easily
         if not Validator.validate(program_name):
@@ -65,7 +73,11 @@ class AddToDatabase():
             # we'll locally use db for short
             db = self.parent_database_connection._db
 
-            parent_function = db.nodes.create(name=program_name, type='program')
+            parent_function = db.nodes.create(name=program_name,
+                                              type='program',
+                                              uploader=uploader,
+                                              uploader_id=uploader_id,
+                                              date=date)
             self._parent_id = parent_function.id
 
             self._new_tx = db.transaction(using_globals=False, for_query=True)
@@ -360,6 +372,11 @@ class SextantConnection:
     It can be used to create/delete/query programs.
     """
 
+    ProgramWithMetadata = namedtuple('ProgramWithMetadata',
+                                     ['uploader', 'uploader_id',
+                                      'program_name', 'date', 
+                                      'number_of_funcs'])
+
     def __init__(self, url):
         self.url = url
         self._db = GraphDatabase(url)
@@ -381,9 +398,14 @@ class SextantConnection:
         if not Validator.validate(name_of_program):
             raise ValueError(
                 "{} is not a valid program name".format(name_of_program))
+        
+        uploader = getpass.getuser()
+        uploader_id = os.getuid()
 
         return AddToDatabase(sextant_connection=self,
-                             program_name=name_of_program)
+                             program_name=name_of_program,
+                             uploader=uploader, uploader_id=uploader_id,
+                             date=str(datetime.now()))
 
     def delete_program(self, name_of_program):
         """
@@ -435,6 +457,22 @@ class SextantConnection:
 
         return set(result)
 
+    def programs_with_metadata(self):
+        """
+        Returns a set of namedtuples which represent the current database.
+        
+        The namedtuples have .uploader, .uploader_id, .program_name, .date,
+        .number_of_funcs.
+        :return: set of namedtuples
+       
+        """
+        
+        q = ("MATCH (base) WHERE base.type = 'program' "
+             "MATCH (base)-[:subject]->(n)"
+             "RETURN base.uploader, base.uploader_id, base.name, base.date, count(n)")
+        result = self._db.query(q)
+        return {self.ProgramWithMetadata(*res) for res in result}
+
     def check_program_exists(self, program_name):
         """
         Execute query to check whether a program with the given name exists.
