@@ -20,6 +20,7 @@ import requests
 
 import sextant.db_api as db_api
 import sextant.export as export
+import sextant.environment as environment
 import tempfile
 import subprocess
 
@@ -60,14 +61,16 @@ class SVGRenderer(Resource):
         return connection.get_all_functions_calling(progname, funcname)
 
     @staticmethod
-    def get_plot(program, suppress_common_functions=False):
-        graph_dot = export.ProgramConverter.to_dot(program, suppress_common_functions)
+    def get_plot(program, suppress_common_functions=False, remove_self_calls=False):
+        graph_dot = export.ProgramConverter.to_dot(program, suppress_common_functions,
+                                                   remove_self_calls=remove_self_calls)
 
         file_written_to = tempfile.NamedTemporaryFile(delete=False)
         file_out = tempfile.NamedTemporaryFile(delete=False)
         file_written_to.write(graph_dot)
         file_written_to.close()
-        subprocess.call(['dot', '-Tsvg', '-Kdot', '-o', file_out.name, file_written_to.name])
+        subprocess.call(['dot', '-Tsvg', '-Kdot', '-o', file_out.name,
+                         file_written_to.name])
 
         output = file_out.read().encode()
         file_out.close()
@@ -81,7 +84,6 @@ class SVGRenderer(Resource):
             request.finish()
             defer.returnValue(None)
 
-        logging.info('enter')
         name = request.args["program_name"][0]
 
         try:
@@ -103,16 +105,14 @@ class SVGRenderer(Resource):
             defer.returnValue(None)
             neo4jconnection = None  # to silence the "referenced before assignment" warnings later
 
-        logging.info('created')
         exists = yield deferToThread(self.check_program_exists, neo4jconnection, name)
         if not exists:
             request.setResponseCode(404)
-            logging.info('returning nonexistent')
+            logging.debug('returning nonexistent')
             request.write("Name %s not found." % (escape(name)))
             request.finish()
             defer.returnValue(None)
 
-        logging.info('done created')
         allowed_queries = ("whole_program", "functions_calling", "functions_called_by", "call_paths", "shortest_path")
 
         if "query" not in request.args:
@@ -147,7 +147,7 @@ class SVGRenderer(Resource):
                 defer.returnValue(None)
             func1 = request.args['func1'][0]
             program = yield deferToThread(neo4jconnection.get_all_functions_called, name, func1)
-        elif query == 'call_paths':
+        elif query == 'all_call_paths':
             if 'func1' not in request.args:
                 # raise 400 Bad Request error
                 request.setResponseCode(400)
@@ -164,7 +164,7 @@ class SVGRenderer(Resource):
             func1 = request.args['func1'][0]
             func2 = request.args['func2'][0]
             program = yield deferToThread(neo4jconnection.get_call_paths, name, func1, func2)
-        elif query == 'shortest_path':
+        elif query == 'shortest_call_path':
             if 'func1' not in request.args:
                 # raise 400 Bad Request error
                 request.setResponseCode(400)
@@ -195,17 +195,16 @@ class SVGRenderer(Resource):
             request.finish()
             defer.returnValue(None)
 
-        logging.info('getting plot')
-        logging.info(program)
+        logging.debug('getting plot')
         if not program.functions:  # we got an empty program back:  the program is in the Sextant but has no functions
             request.setResponseCode(204)
             request.finish()
             defer.returnValue(None)
-
-        output = yield deferToThread(self.get_plot, program, suppress_common)
+        output = yield deferToThread(self.get_plot, program, suppress_common,
+                                     remove_self_calls=False)
         request.setHeader("content-type", "image/svg+xml")
 
-        logging.info('SVG: return')
+        logging.debug('SVG: return')
         request.write(output)
         request.finish()
 
@@ -239,8 +238,6 @@ class GraphProperties(Resource):
 
         query = request.args['query'][0]
 
-        logging.info('Properties: about to get_connection')
-
         try:
             neo4j_connection = yield deferToThread(self._get_connection)
         except Exception:
@@ -250,8 +247,6 @@ class GraphProperties(Resource):
             defer.returnValue(None)
             neo4j_connection = None  # just to silence the "referenced before assignment" warnings
 
-        logging.info('got connection')
-
         if query == 'programs':
             request.setHeader("content-type", "application/json")
             prognames = yield deferToThread(self._get_program_names, neo4j_connection)
@@ -298,9 +293,7 @@ def serve_site(input_database_url='http://localhost:7474', port=2905):
     global database_url
     database_url = input_database_url
     # serve static directory at root
-    root = File(os.path.join(
-        os.path.dirname(os.path.abspath(__file__)),
-        "..", "..", "resources", "sextant", "web"))
+    root = File(os.path.join(environment.RESOURCES_DIR, 'sextant', 'web'))
 
     # serve a dynamic Echoer webpage at /echoer.html
     root.putChild("echoer.html", Echoer())
